Module: Devise::Models
- Defined in:
- lib/devise/models/password_hashable.rb
Overview
Namespace for the model concerns Devise mixes into your models.
Defined Under Namespace
Modules: PasswordHashable
Namespace for the model concerns Devise mixes into your models.
Modules: PasswordHashable